==> haskell-microstache-1.0.2.3-204.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-8fnrAQb2wwZcWgs9AtzqU
key:                  microstache-1.0.2.3-8fnrAQb2wwZcWgs9AtzqU
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  f03f8b1929caeb4308e260d987838076
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-8fnrAQb2wwZcWgs9AtzqU
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    parsec-3.1.16.1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.2.3-205-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-KKsw6fNygFtG16m7n2m4CK
key:                  microstache-1.0.2.3-KKsw6fNygFtG16m7n2m4CK
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  18cf473bc23151722a830ba3a0663308
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-KKsw6fNygFtG16m7n2m4CK
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    parsec-3.1.16.1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
